@@ -1,5 +1,5 @@
 #
-# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/GnomeCanvas/Canvas.pm,v 1.9 2003/11/14 05:00:00 muppetman Exp $
+# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/GnomeCanvas/Canvas.pm,v 1.12 2004/01/09 04:50:13 muppetman Exp $
 #
 
 package Gnome2::Canvas;
@@ -14,7 +14,7 @@ require DynaLoader;
 
 our @ISA = qw(DynaLoader);
 
-our $VERSION = '0.34';
+our $VERSION = '0.90';
 
 sub dl_load_flags { 0x01 }
 
@@ -24,14 +24,13 @@ bootstrap Gnome2::Canvas $VERSION;
 
 1;
 __END__
-# Below is stub documentation for your module. You'd better edit it!
 
-=head1 NAME
-
-Gnome2::Canvas - Perl interface to the Gnome Canvas
+# this pod is included in the pod generated for Gnome2::Canvas from
+# the xs source by Glib::GenPod.  NAME is not necessary.
 
 =head1 SYNOPSIS
 
+  use Gtk2 -init;
   use Gnome2::Canvas;
   $win = Gtk2::Window->new;
   $frame = Gtk2::Frame->new;
@@ -55,10 +54,6 @@ Gnome2::Canvas - Perl interface to the Gnome Canvas
   
   Gtk2->main;
 
-=head1 ABSTRACT
-
-  Perl bindings to the 2.x series of the Gnome Canvas widget.
-
 =head1 DESCRIPTION
 
 The Gnome2::Canvas module allows a perl developer to use the Gnome Canvas.
@@ -82,9 +77,8 @@ Gnome2::Canvas::index(3pm) lists the generated Perl API reference PODs.
 
 =head1 AUTHOR
 
-muppet E<lt>scott at asofyet dot orgE<gt>
-
-If you want to own this project, please let me know.
+muppet <scott at asofyet dot org>, with patches from
+Torsten Schoenfeld <kaffetisch at web dot de>.
 
 =head1 COPYRIGHT AND LICENSE
 
